############################################################################################################################
############################################################################################################################
###R-script used to model the spatio-temporal trend of rusa deer abundance and resident complaints in peri-urban landscape in eastern Australia

###Part of supplementary materials for research article:
#Intensive professional vehicle-based shooting provides local control of invasive rusa deer in a peri-urban landscape.
#Sebastien Comte, Andrew J. Bengsen, Calum X. Cunningham, Michelle Dawson, Anthony R. Pople, David M. Forsyth

#Corresponding author. Email: sebastien.comte@dpi.nsw.gov.au

############################################################################################################################
############################################################################################################################
###Packages required to run the script
library(tidyverse); library(inlabru); library(INLA);library(raster)

######################################################################################################################
######################################################################################################################
######################################################################################################################
###R-script to fit a joint-likelihood model for deer relative abundance in peri-urban landscape

###Load the study area boundary provided as the shapefile: boundary.shp
approxBoundary <- readOGR('.../boundary.shp', layer="boundary")
proj <- approxBoundary@proj4string@projargs

###Create the mesh using coarser mesh size beyond boundary and clipping to actual boundary when it comes to prediction
mesh <- inla.mesh.2d(boundary = approxBoundary, max.edge = c(2000, 5000))
mesh$segm$bnd$crs <- proj

###Create the Matern correlation structure. See inlabru help file for explanation of the priors. 
matern <- inla.spde2.pcmatern(mesh,  prior.sigma = c(1, 0.5), prior.range = c(5000, 0.5))             

###Loading the shooting dataset
shoot <- read.csv(file=".../shoot.csv",header=T, na.strings="NA")

###Loading the faecal pellet counts
fpi <- read.csv(file=".../fpi.csv",header=T, na.strings="NA")


####################################################################################################
###Create spatial points to fit the model:
s_xy <- shoot[,c("x","y")]
s_df <- as.data.frame(shoot[,c(1:18)])
s_spdf <- SpatialPointsDataFrame(s_xy,s_df)
s_spdf@proj4string@projargs <- proj

f_xy <- fpi[,c("x","y")]
f_df <- as.data.frame(fpi[,c(1:10)])
f_spdf <- SpatialPointsDataFrame(f_xy,f_df)
f_spdf@proj4string@projargs <- proj


###Create one-dimensional mesh for non linear effect of month on deer sightings
mesh1D_month <- inla.mesh.1d(loc = seq(1, max(s_spdf$month), length=6), boundary="cyclic") #January and December should be similar


###Matern correlation structure for the covariate month
range = c(0.1, 0.2)
sigma = c(10,0.5)

spde_month <- inla.spde2.pcmatern(mesh1D_month, prior.range = range, prior.sigma = sigma)

################################################################################################################
###########################################################################################################
###Joint-likelihood modelling of deer sightings and faecal pellet counts

# set inlabru options
c.c <- list(cpo = T, dic = T, waic = T, config = T)


#Model
cmpJoint = ~Intercept_obs(1) +
  Intercept_fpi(1) +
  tree +
  tree2 +
  t +
  t2 +
  road +
  slope +
  slope2 +
  myField_month(main = month, model = spde_month) +
  myField_coords(main = coordinates, 
                 group = year_con,
                 model = inla.spde2.pcmatern(mesh,                              
                                             prior.sigma = c(1, 0.1),            
                                             prior.range = c(5000, 0.5), 
                                             alpha=1.5),
                 control.group = list(model = "ar1"))


# create likelihoods for the observation with some parameters shared between the sub-models. 
like_obs <- inlabru::like(formula = obs.tot ~ Intercept_obs + road + tree + tree2 + slope + slope2 + myField_month + myField_coords, 
                          family = "nbinomial", data = s_spdf)
like_fpi <- inlabru::like(formula = pellet ~  Intercept_fpi + t + t2 + road + slope + slope2 + myField_coords,
                          family = "nbinomial", data = f_spdf)
fitJoint <- bru(cmpJoint, like_obs, like_fpi,   options = list(control.compute = c.c))    


######################################################################################################################
######################################################################################################################
######################################################################################################################
###R-script for spatio-temporal trends in resident complaints about rusa deer impacts


###Load the study area boundary provided as the shapefile: bound_comp.shp
approxBoundary <- readOGR('.../bound_comp.shp', layer="bound_comp")
proj <- approxBoundary@proj4string@projargs

###Create the mesh using coarser mesh size beyond boundary and clipping to actual boundary when it comes to prediction
mesh <- inla.mesh.2d(boundary = approxBoundary, max.edge = c(2000, 5000))
mesh$segm$bnd$crs <- proj

###Create the Matern correlation structure. See inlabru help file for explanation of the priors. 
matern <- inla.spde2.pcmatern(mesh,  prior.sigma = c(0.1, 0.1), prior.range = c(1000, 0.1))             

###Loading the faecal pellet counts
comp <- read.csv(file=".../complaints.csv",header=T, na.strings="NA")


####################################################################################################
###Create spatial points to fit the model:
c_xy <- comp[,c("x","y")]
c_df <- as.data.frame(comp[,c(1:9)])
c_spdf <- SpatialPointsDataFrame(c_xy,c_df)
c_spdf@proj4string@projargs <- proj

# create one-dimensional mesh for non linear effect of month
mesh1D_month <- inla.mesh.1d(loc = seq(1, max(c_spdf$month), length=6), boundary="cyclic") #January and December should be similar

# Matern correlation structure for the covariate month
range = c(0.1, 0.2)
sigma = c(10,0.5)

spde_month <- inla.spde2.pcmatern(mesh1D_month, prior.range = range, prior.sigma = sigma)

# set inlabru options
c.c <- list(cpo = T, dic = T, waic = T, config = T)

#alternative model
cmp = ~
  Intercept1(1) +
  myField_month(main = month, model = spde_month) +
  road +
  road2 +
  tree +
  tree2 +
  slope +
  slope2 +
  myField_coords(main = coordinates, 
                 group = year_con,
                 model = inla.spde2.pcmatern(mesh,                              
                                             prior.sigma = c(1, 0.1),            
                                             prior.range = c(5000, 0.5), 
                                             alpha=1.5),
                 control.group = list(model = "ar1"))



# Fit the model for complaints grouped by rut season
comp.like <- inlabru::like(formula = comp ~ Intercept1 + myField_month + road + road2 + tree + tree2 + slope + slope2 + myField_coords, 
                           family = "binomial", data = c_spdf)

comp.fit <- bru(cmp,comp.like, options = list(control.compute = c.c)) 






